# coding: utf-8

"""
Trading API

API for automated trading and exchange interface. This API is used to trade on the exchange and manage bots, API keys, orders, and more.

The version of the OpenAPI document: 2.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set, Union

from pydantic import (
    BaseModel,
    ConfigDict,
    Field,
    StrictBool,
    StrictFloat,
    StrictInt,
    StrictStr,
)
from typing_extensions import Self


class VaultDetails(BaseModel):
    """
    Model for vault details
    """  # noqa: E501

    name: StrictStr = Field(description="Vault name")
    vault_address: StrictStr = Field(description="Vault address")
    leader: StrictStr = Field(description="Vault leader address")
    description: StrictStr = Field(description="Vault description")
    apr: Union[StrictFloat, StrictInt] = Field(description="Annual percentage rate")
    leader_fraction: Union[StrictFloat, StrictInt] = Field(
        description="Leader fraction"
    )
    leader_commission: Union[StrictFloat, StrictInt] = Field(
        description="Leader commission"
    )
    max_distributable: Union[StrictFloat, StrictInt] = Field(
        description="Maximum distributable amount"
    )
    max_withdrawable: Union[StrictFloat, StrictInt] = Field(
        description="Maximum withdrawable amount"
    )
    is_closed: StrictBool = Field(description="Whether the vault is closed")
    allow_deposits: StrictBool = Field(description="Whether deposits are allowed")
    tvl: Union[StrictFloat, StrictInt] = Field(description="Current TVL of the vault")
    __properties: ClassVar[List[str]] = [
        "name",
        "vault_address",
        "leader",
        "description",
        "apr",
        "leader_fraction",
        "leader_commission",
        "max_distributable",
        "max_withdrawable",
        "is_closed",
        "allow_deposits",
        "tvl",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of VaultDetails from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of VaultDetails from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "name": obj.get("name"),
                "vault_address": obj.get("vault_address"),
                "leader": obj.get("leader"),
                "description": obj.get("description"),
                "apr": obj.get("apr"),
                "leader_fraction": obj.get("leader_fraction"),
                "leader_commission": obj.get("leader_commission"),
                "max_distributable": obj.get("max_distributable"),
                "max_withdrawable": obj.get("max_withdrawable"),
                "is_closed": obj.get("is_closed"),
                "allow_deposits": obj.get("allow_deposits"),
                "tvl": obj.get("tvl"),
            }
        )
        return _obj
