# coding: utf-8

# flake8: noqa

"""
DEX AI API

API for DEX AI

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "SignalsApi",
    "StatusApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ApiErrorIdentifier",
    "ApiErrorLevel",
    "ApiErrorType",
    "ExceptionDetail",
    "PaginatedResponseSignalWithToken",
    "Risk",
    "SignalOverviewStats",
    "SignalVolume",
    "SignalWithToken",
    "TokenData",
    "TokenDetail",
]

# import apis into sdk package
from crypticorn.dex.client.api.signals_api import SignalsApi as SignalsApi
from crypticorn.dex.client.api.status_api import StatusApi as StatusApi
from crypticorn.dex.client.api_client import ApiClient as ApiClient

# import ApiClient
from crypticorn.dex.client.api_response import ApiResponse as ApiResponse
from crypticorn.dex.client.configuration import Configuration as Configuration
from crypticorn.dex.client.exceptions import ApiAttributeError as ApiAttributeError
from crypticorn.dex.client.exceptions import ApiException as ApiException
from crypticorn.dex.client.exceptions import ApiKeyError as ApiKeyError
from crypticorn.dex.client.exceptions import ApiTypeError as ApiTypeError
from crypticorn.dex.client.exceptions import ApiValueError as ApiValueError
from crypticorn.dex.client.exceptions import OpenApiException as OpenApiException

# import models into sdk package
from crypticorn.dex.client.models.api_error_identifier import (
    ApiErrorIdentifier as ApiErrorIdentifier,
)
from crypticorn.dex.client.models.api_error_level import ApiErrorLevel as ApiErrorLevel
from crypticorn.dex.client.models.api_error_type import ApiErrorType as ApiErrorType
from crypticorn.dex.client.models.exception_detail import (
    ExceptionDetail as ExceptionDetail,
)
from crypticorn.dex.client.models.paginated_response_signal_with_token import (
    PaginatedResponseSignalWithToken as PaginatedResponseSignalWithToken,
)
from crypticorn.dex.client.models.risk import Risk as Risk
from crypticorn.dex.client.models.signal_overview_stats import (
    SignalOverviewStats as SignalOverviewStats,
)
from crypticorn.dex.client.models.signal_volume import SignalVolume as SignalVolume
from crypticorn.dex.client.models.signal_with_token import (
    SignalWithToken as SignalWithToken,
)
from crypticorn.dex.client.models.token_data import TokenData as TokenData
from crypticorn.dex.client.models.token_detail import TokenDetail as TokenDetail
