# coding: utf-8

# flake8: noqa
"""
Hive AI API

API for Hive AI model training and evaluation

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


# import models into model package
from crypticorn.hive.client.models.api_error_identifier import ApiErrorIdentifier
from crypticorn.hive.client.models.api_error_level import ApiErrorLevel
from crypticorn.hive.client.models.api_error_type import ApiErrorType
from crypticorn.hive.client.models.coin_info import CoinInfo
from crypticorn.hive.client.models.coins import Coins
from crypticorn.hive.client.models.data_download_response import DataDownloadResponse
from crypticorn.hive.client.models.data_info import DataInfo
from crypticorn.hive.client.models.data_options import DataOptions
from crypticorn.hive.client.models.data_version import DataVersion
from crypticorn.hive.client.models.data_version_info import DataVersionInfo
from crypticorn.hive.client.models.download_links import DownloadLinks
from crypticorn.hive.client.models.evaluation import Evaluation
from crypticorn.hive.client.models.evaluation_response import EvaluationResponse
from crypticorn.hive.client.models.exception_detail import ExceptionDetail
from crypticorn.hive.client.models.feature_size import FeatureSize
from crypticorn.hive.client.models.model_create import ModelCreate
from crypticorn.hive.client.models.model_read import ModelRead
from crypticorn.hive.client.models.model_status import ModelStatus
from crypticorn.hive.client.models.model_update import ModelUpdate
from crypticorn.hive.client.models.target import Target
from crypticorn.hive.client.models.target_info import TargetInfo
from crypticorn.hive.client.models.target_type import TargetType
