# coding: utf-8

# flake8: noqa

"""
Marketcap Service API

API for retrieving historical marketcap data, available exchanges, and indicators.

The version of the OpenAPI document: 1.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "ExchangesApi",
    "IndicatorsApi",
    "LogsApi",
    "MarketcapApi",
    "MarketsApi",
    "QuoteCurrenciesApi",
    "StatusApi",
    "TokensApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ApiErrorIdentifier",
    "ApiErrorLevel",
    "ApiErrorType",
    "ExceptionDetail",
    "ExchangeAvailability",
    "ExchangeMapping",
    "InternalExchange",
    "MarketType",
    "MarketcapRanking",
    "MarketcapSymbolRanking",
    "OHLCV",
    "Severity",
    "TimeInterval",
    "TradingStatus",
]

# import apis into sdk package
from crypticorn.metrics.client.api.exchanges_api import ExchangesApi as ExchangesApi
from crypticorn.metrics.client.api.indicators_api import IndicatorsApi as IndicatorsApi
from crypticorn.metrics.client.api.logs_api import LogsApi as LogsApi
from crypticorn.metrics.client.api.marketcap_api import MarketcapApi as MarketcapApi
from crypticorn.metrics.client.api.markets_api import MarketsApi as MarketsApi
from crypticorn.metrics.client.api.quote_currencies_api import (
    QuoteCurrenciesApi as QuoteCurrenciesApi,
)
from crypticorn.metrics.client.api.status_api import StatusApi as StatusApi
from crypticorn.metrics.client.api.tokens_api import TokensApi as TokensApi
from crypticorn.metrics.client.api_client import ApiClient as ApiClient

# import ApiClient
from crypticorn.metrics.client.api_response import ApiResponse as ApiResponse
from crypticorn.metrics.client.configuration import Configuration as Configuration
from crypticorn.metrics.client.exceptions import ApiAttributeError as ApiAttributeError
from crypticorn.metrics.client.exceptions import ApiException as ApiException
from crypticorn.metrics.client.exceptions import ApiKeyError as ApiKeyError
from crypticorn.metrics.client.exceptions import ApiTypeError as ApiTypeError
from crypticorn.metrics.client.exceptions import ApiValueError as ApiValueError
from crypticorn.metrics.client.exceptions import OpenApiException as OpenApiException

# import models into sdk package
from crypticorn.metrics.client.models.api_error_identifier import (
    ApiErrorIdentifier as ApiErrorIdentifier,
)
from crypticorn.metrics.client.models.api_error_level import (
    ApiErrorLevel as ApiErrorLevel,
)
from crypticorn.metrics.client.models.api_error_type import ApiErrorType as ApiErrorType
from crypticorn.metrics.client.models.exception_detail import (
    ExceptionDetail as ExceptionDetail,
)
from crypticorn.metrics.client.models.exchange_availability import (
    ExchangeAvailability as ExchangeAvailability,
)
from crypticorn.metrics.client.models.exchange_mapping import (
    ExchangeMapping as ExchangeMapping,
)
from crypticorn.metrics.client.models.internal_exchange import (
    InternalExchange as InternalExchange,
)
from crypticorn.metrics.client.models.market_type import MarketType as MarketType
from crypticorn.metrics.client.models.marketcap_ranking import (
    MarketcapRanking as MarketcapRanking,
)
from crypticorn.metrics.client.models.marketcap_symbol_ranking import (
    MarketcapSymbolRanking as MarketcapSymbolRanking,
)
from crypticorn.metrics.client.models.ohlcv import OHLCV as OHLCV
from crypticorn.metrics.client.models.severity import Severity as Severity
from crypticorn.metrics.client.models.time_interval import TimeInterval as TimeInterval
from crypticorn.metrics.client.models.trading_status import (
    TradingStatus as TradingStatus,
)
