# coding: utf-8

# flake8: noqa

"""
Trading API

API for automated trading and exchange interface. This API is used to trade on the exchange and manage bots, API keys, orders, and more.

The version of the OpenAPI document: 2.0.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "APIKeysApi",
    "BotsApi",
    "StatusApi",
    "StrategiesApi",
    "TradingActionsApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "Bot",
    "BotCreate",
    "BotUpdate",
    "ExchangeKey",
    "ExchangeKeyCreate",
    "ExchangeKeyUpdate",
    "ExecutionIds",
    "FuturesTradingAction",
    "FuturesTradingActionCreate",
    "Order",
    "OrdersCount",
    "PaginatedResponseFuturesTradingAction",
    "PaginatedResponseOrder",
    "PnL",
    "PostFuturesAction",
    "SpotTradingActionCreate",
    "Strategy",
    "StrategyCreate",
    "StrategyUpdate",
    "TPSL",
    "TPSLCreate",
    "TradingActionType",
    "VaultBot",
    "VaultDetails",
]

# import apis into sdk package
from crypticorn.trade.client.api.api_keys_api import APIKeysApi as APIKeysApi
from crypticorn.trade.client.api.bots_api import BotsApi as BotsApi
from crypticorn.trade.client.api.status_api import StatusApi as StatusApi
from crypticorn.trade.client.api.strategies_api import StrategiesApi as StrategiesApi
from crypticorn.trade.client.api.trading_actions_api import (
    TradingActionsApi as TradingActionsApi,
)
from crypticorn.trade.client.api_client import ApiClient as ApiClient

# import ApiClient
from crypticorn.trade.client.api_response import ApiResponse as ApiResponse
from crypticorn.trade.client.configuration import Configuration as Configuration
from crypticorn.trade.client.exceptions import ApiAttributeError as ApiAttributeError
from crypticorn.trade.client.exceptions import ApiException as ApiException
from crypticorn.trade.client.exceptions import ApiKeyError as ApiKeyError
from crypticorn.trade.client.exceptions import ApiTypeError as ApiTypeError
from crypticorn.trade.client.exceptions import ApiValueError as ApiValueError
from crypticorn.trade.client.exceptions import OpenApiException as OpenApiException

# import models into sdk package
from crypticorn.trade.client.models.bot import Bot as Bot
from crypticorn.trade.client.models.bot_create import BotCreate as BotCreate
from crypticorn.trade.client.models.bot_update import BotUpdate as BotUpdate
from crypticorn.trade.client.models.exchange_key import ExchangeKey as ExchangeKey
from crypticorn.trade.client.models.exchange_key_create import (
    ExchangeKeyCreate as ExchangeKeyCreate,
)
from crypticorn.trade.client.models.exchange_key_update import (
    ExchangeKeyUpdate as ExchangeKeyUpdate,
)
from crypticorn.trade.client.models.execution_ids import ExecutionIds as ExecutionIds
from crypticorn.trade.client.models.futures_trading_action import (
    FuturesTradingAction as FuturesTradingAction,
)
from crypticorn.trade.client.models.futures_trading_action_create import (
    FuturesTradingActionCreate as FuturesTradingActionCreate,
)
from crypticorn.trade.client.models.order import Order as Order
from crypticorn.trade.client.models.orders_count import OrdersCount as OrdersCount
from crypticorn.trade.client.models.paginated_response_futures_trading_action import (
    PaginatedResponseFuturesTradingAction as PaginatedResponseFuturesTradingAction,
)
from crypticorn.trade.client.models.paginated_response_order import (
    PaginatedResponseOrder as PaginatedResponseOrder,
)
from crypticorn.trade.client.models.pn_l import PnL as PnL
from crypticorn.trade.client.models.post_futures_action import (
    PostFuturesAction as PostFuturesAction,
)
from crypticorn.trade.client.models.spot_trading_action_create import (
    SpotTradingActionCreate as SpotTradingActionCreate,
)
from crypticorn.trade.client.models.strategy import Strategy as Strategy
from crypticorn.trade.client.models.strategy_create import (
    StrategyCreate as StrategyCreate,
)
from crypticorn.trade.client.models.strategy_update import (
    StrategyUpdate as StrategyUpdate,
)
from crypticorn.trade.client.models.tpsl import TPSL as TPSL
from crypticorn.trade.client.models.tpsl_create import TPSLCreate as TPSLCreate
from crypticorn.trade.client.models.trading_action_type import (
    TradingActionType as TradingActionType,
)
from crypticorn.trade.client.models.vault_bot import VaultBot as VaultBot
from crypticorn.trade.client.models.vault_details import VaultDetails as VaultDetails
